@@ -1,6 +1,6 @@
-;;; solarized-dark-theme.el --- Solarized Dark Theme for Emacs.
+;;; solarized-dark-theme.el --- Solarized Dark Theme for Emacs  -*- lexical-binding: t -*-
 
-;; Copyright (C) 2011-2019 Bozhidar Batsov
+;; Copyright (C) 2011-2021 Bozhidar Batsov
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -22,12 +22,20 @@
 ;;; Code:
 
 (require 'solarized)
+(eval-when-compile
+  (require 'solarized-palettes))
 
 (deftheme solarized-dark "The dark variant of the Solarized colour theme")
 
-(create-solarized-theme 'dark 'solarized-dark)
+(solarized-with-color-variables 'dark 'solarized-dark
+  solarized-dark-color-palette-alist)
 
 (provide-theme 'solarized-dark)
 
 (provide 'solarized-dark-theme)
+
+;; Local Variables:
+;; indent-tabs-mode: nil
+;; End:
+
 ;;; solarized-dark-theme.el ends here
